@@ -48,17 +48,10 @@ typedef enum
   GDK_OSX_SNOW_LEOPARD = 6,
   GDK_OSX_LION = 7,
   GDK_OSX_MOUNTAIN_LION = 8,
-  GDK_OSX_MAVERICKS = 9,
-  GDK_OSX_YOSEMITE = 10,
-  GDK_OSX_EL_CAPITAN = 11,
-  GDK_OSX_SIERRA = 12,
-  GDK_OSX_HIGH_SIERRA = 13,
-  GDK_OSX_MOJAVE = 14,
-  GDK_OSX_CURRENT = 14,
+  GDK_OSX_CURRENT = 8,
   GDK_OSX_NEW = 99
 } GdkOSXVersion;
 
-gboolean  gdk_quartz_window_is_quartz                           (GdkWindow      *window);
 NSWindow *gdk_quartz_window_get_nswindow                        (GdkWindow      *window);
 NSView   *gdk_quartz_window_get_nsview                          (GdkWindow      *window);
 NSImage  *gdk_quartz_pixbuf_to_ns_image_libgtk_only             (GdkPixbuf      *pixbuf);
